@@ -1,5 +1,5 @@
 """Geometry operations on GeoArrow memory."""
 
-from .bbox import total_bounds
-from .centroid import weighted_centroid
+from .bbox import Bbox, total_bounds
+from .centroid import WeightedCentroid, weighted_centroid
 from .reproject import reproject_column, reproject_table
