@@ -1,33 +1,39 @@
 from __future__ import annotations
 
-from io import StringIO
+import warnings
+from dataclasses import replace
 from pathlib import Path
 from typing import IO, TYPE_CHECKING, Any, TextIO, overload
 
 import ipywidgets
-import traitlets
-import traitlets as t
-from ipywidgets import CallbackDispatcher
-from ipywidgets.embed import dependency_state, embed_minimal_html
+import numpy as np
+import traitlets.traitlets as t
+from ipywidgets import CallbackDispatcher, VBox
 
 from lonboard._base import BaseAnyWidget
-from lonboard._layer import BaseLayer
+from lonboard._exception_display import ErrorOutput
+from lonboard._html_export import map_to_html
 from lonboard._viewport import compute_view
-from lonboard.basemap import CartoBasemap
-from lonboard.traits import (
-    DEFAULT_INITIAL_VIEW_STATE,
-    BasemapUrl,
-    HeightTrait,
-    VariableLengthTuple,
-    ViewStateTrait,
+from lonboard.basemap import CartoStyle, MaplibreBasemap
+from lonboard.controls import (
+    BaseControl,
+    FullscreenControl,
+    NavigationControl,
+    ScaleControl,
 )
+from lonboard.experimental.view import BaseView, GlobeView, MapView
+from lonboard.layer import BaseLayer
+from lonboard.traits import MapHeightTrait, VariableLengthTuple, ViewStateTrait
+from lonboard.view_state import BaseViewState, GlobeViewState, MapViewState
 
 if TYPE_CHECKING:
     import sys
     from collections.abc import Callable, Sequence
+    from typing import Self
 
     from IPython.display import HTML  # type: ignore
 
+    from lonboard._validators.types import TraitProposal
     from lonboard.types.map import MapKwargs
 
     if sys.version_info >= (3, 12):
@@ -39,28 +45,9 @@ if TYPE_CHECKING:
 # bundler yields lonboard/static/{index.js,styles.css}
 bundler_output_dir = Path(__file__).parent / "static"
 
-# HTML template to override exported map as 100% height
-_HTML_TEMPLATE = """<!DOCTYPE html>
-<html lang="en">
-<head>
-    <meta charset="UTF-8">
-    <title>{title}</title>
-</head>
-<style>
-    html {{ height: 100%; }}
-    body {{ height: 100%; overflow: hidden;}}
-    .widget-subarea {{ height: 100%; }}
-    .jupyter-widgets-disconnected {{ height: 100%; }}
-</style>
-<body>
-{snippet}
-</body>
-</html>
-"""
-
 
 class Map(BaseAnyWidget):
-    """The top-level class used to display a map in a Jupyter Widget.
+    """An interactive Map.
 
     **Example:**
 
@@ -89,6 +76,8 @@ class Map(BaseAnyWidget):
     def __init__(
         self,
         layers: BaseLayer | Sequence[BaseLayer],
+        *,
+        basemap_style: str | CartoStyle | None = None,
         **kwargs: Unpack[MapKwargs],
     ) -> None:
         """Create a new Map.
@@ -100,12 +89,28 @@ class Map(BaseAnyWidget):
             layers: One or more layers to render on this map.
 
         Keyword Args:
-            kwargs: Passed on to class variables.
+            basemap_style: DEPRECATED. Use `basemap` instead. A URL to a MapLibre-compatible basemap style.
+
+                Various styles are provided in [`lonboard.basemap`](https://developmentseed.org/lonboard/latest/api/basemap/).
+
+            kwargs: Passed on to class variables. For example, you can pass `height=600` to pass that value on to the [`height`][lonboard.Map.height] attribute.
 
         Returns:
             A Map object.
 
         """
+        if basemap_style is not None:
+            warnings.warn(
+                "`basemap_style` is deprecated and will be removed in 0.14. Use `basemap` instead.",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+            if "basemap" in kwargs:
+                raise ValueError(
+                    "Cannot pass both `basemap_style` and `basemap`. Use only `basemap`.",
+                )
+            kwargs["basemap"] = MaplibreBasemap(style=basemap_style)
+
         if isinstance(layers, BaseLayer):
             layers = [layers]
 
@@ -115,7 +120,9 @@ class Map(BaseAnyWidget):
             buffers: list[bytes],  # noqa: ARG001
         ) -> None:
             if msg.get("kind") == "on-click":
-                self._click_handlers(tuple(msg.get("coordinate")))
+                coord = msg.get("coordinate")
+                if coord is not None:
+                    self._click_handlers(tuple(coord))
 
         super().__init__(layers=layers, **kwargs)
         self._click_handlers = CallbackDispatcher()
@@ -123,6 +130,19 @@ class Map(BaseAnyWidget):
         self.layout.height = "100%"
         self.layout.width = "100%"
 
+        self._error_output = ErrorOutput(name=self.__class__.__name__)
+
+    def _repr_mimebundle_(self, **kwargs: Any) -> tuple[dict, dict] | None:
+        # Insert a display Output after the map for rendering exceptions from callbacks
+        # and from JS code
+        error_outputs = [layer._error_output for layer in self.layers]  # noqa: SLF001
+        error_vbox = VBox(
+            [self._error_output, *error_outputs],
+            layout={"max_height": "200px", "overflow": "auto"},
+        )
+        container = VBox([self, error_vbox])
+        return container._repr_mimebundle_(**kwargs)
+
     def on_click(self, callback: Callable, *, remove: bool = False) -> None:
         """Register a callback to execute when the map is clicked.
 
@@ -151,11 +171,13 @@ class Map(BaseAnyWidget):
     _esm = bundler_output_dir / "index.js"
     _css = bundler_output_dir / "index.css"
 
-    view_state = ViewStateTrait()
+    view_state: BaseViewState | None = ViewStateTrait()  # type: ignore
     """
     The view state of the map.
 
-    - Type: [`ViewState`][lonboard.models.ViewState]
+    - Type: A subclass of [`BaseViewState`][lonboard.view_state.BaseViewState], such as
+        [`MapViewState`][lonboard.view_state.MapViewState] or
+        [`GlobeViewState`][lonboard.view_state.GlobeViewState].
     - Default: Automatically inferred from the data passed to the map.
 
     You can initialize the map to a specific view state using this property:
@@ -174,24 +196,72 @@ class Map(BaseAnyWidget):
         once it's been initially rendered.
 
     """
+
     _has_click_handlers = t.Bool(default_value=False, allow_none=False).tag(sync=True)
     """
     Indicates if a click handler has been registered.
     """
 
-    height = HeightTrait().tag(sync=True)
+    height = MapHeightTrait().tag(sync=True)
     """Height of the map in pixels, or valid CSS height property.
 
-    This API is not yet stabilized and may change in the future.
+    For example, it can be `600` (pixels) or `"75vh"` (75% of the viewport height).
+
+    - Type: `int` or `str`
+    - Default: full height of the containing cell.
     """
 
     layers = VariableLengthTuple(t.Instance(BaseLayer)).tag(
         sync=True,
         **ipywidgets.widget_serialization,
     )
-    """One or more `Layer` objects to display on this map.
+    """One or more [`Layer`][lonboard.BaseLayer] objects to display on this map.
     """
 
+    controls = VariableLengthTuple(
+        t.Instance(BaseControl),
+        default_value=(
+            FullscreenControl(),
+            NavigationControl(),
+            ScaleControl(),
+        ),
+    ).tag(
+        sync=True,
+        **ipywidgets.widget_serialization,
+    )
+    """One or more map controls to display on this map.
+
+    See [`lonboard.controls`][] for available controls.
+    """
+
+    view: t.Instance[BaseView | None] = t.Instance(BaseView, allow_none=True).tag(
+        sync=True,
+        **ipywidgets.widget_serialization,
+    )
+    """The view to use for this map.
+
+    Views represent the "camera(s)" (essentially viewport dimensions and projection matrices) that you look at your data with. deck.gl offers multiple view types for both geospatial and non-geospatial use cases. Read the [Views and Projections](https://deck.gl/docs/developer-guide/views) guide for the concept and examples.
+
+    See [`lonboard.experimental.view`][] for available view types.
+    """
+
+    @t.validate("view")
+    def _validate_view(
+        self,
+        proposal: TraitProposal[t.Instance[BaseView | None], BaseView, Self],
+    ) -> BaseView:
+        # if proposed view is a globe view, ensure that basemap is interleaved
+        if (
+            isinstance(proposal["value"], GlobeView)
+            and self.basemap is not None
+            and self.basemap.mode != "interleaved"
+        ):
+            raise t.TraitError(
+                "GlobeView requires the basemap mode to be 'interleaved'. Please set `basemap.mode='interleaved'`.",
+            )
+
+        return proposal["value"]
+
     show_tooltip = t.Bool(default_value=False).tag(sync=True)
     """
     Whether to render a tooltip on hover on the map.
@@ -219,17 +289,67 @@ class Map(BaseAnyWidget):
     - Default: `5`
     """
 
-    basemap_style = BasemapUrl(CartoBasemap.PositronNoLabels)
-    """
-    A URL to a MapLibre-compatible basemap style.
+    basemap: t.Instance[MaplibreBasemap | None] = t.Instance(
+        MaplibreBasemap,
+        # If both `args` and `kw` are None, then the default value is None.
+        # Set empty kw so that the default is MaplibreBasemap() with default params
+        kw={},
+        allow_none=True,
+    ).tag(
+        sync=True,
+        **ipywidgets.widget_serialization,
+    )
+    """A basemap instance.
 
-    Various styles are provided in [`lonboard.basemap`](https://developmentseed.org/lonboard/latest/api/basemap/).
+    See [`lonboard.basemap.MaplibreBasemap`] for more information.
 
-    - Type: `str`, holding a URL hosting a basemap style.
-    - Default
-      [`lonboard.basemap.CartoBasemap.PositronNoLabels`][lonboard.basemap.CartoBasemap.PositronNoLabels]
+    Pass `None` to disable rendering a basemap.
     """
 
+    @t.validate("basemap")
+    def _validate_basemap(
+        self,
+        proposal: TraitProposal[
+            t.Instance[MaplibreBasemap | None],
+            MaplibreBasemap,
+            Self,
+        ],
+    ) -> MaplibreBasemap | None:
+        # If proposed basemap is not interleaved, ensure current view is not globe view
+        if (
+            proposal["value"] is not None
+            and proposal["value"].mode != "interleaved"
+            and isinstance(self.view, GlobeView)
+        ):
+            raise t.TraitError(
+                "GlobeView requires the basemap mode to be 'interleaved'. Please set `basemap.mode='interleaved'`.",
+            )
+
+        return proposal["value"]
+
+    @property
+    def basemap_style(self) -> str | None:
+        """The URL of the basemap style in use."""
+        warnings.warn(
+            "`basemap_style` is deprecated and will be removed in 0.14. Use `basemap` instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+
+        if self.basemap is not None:
+            return self.basemap.style
+
+        return None
+
+    @basemap_style.setter
+    def basemap_style(self, value: str | CartoStyle) -> None:
+        warnings.warn(
+            "`basemap_style` is deprecated and will be removed in 0.14. Use `basemap` instead.",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        self.basemap = MaplibreBasemap(style=value)
+
     custom_attribution = t.Union(
         [
             t.Unicode(allow_none=True),
@@ -302,10 +422,7 @@ class Map(BaseAnyWidget):
     parameters = t.Any(allow_none=True, default_value=None).tag(sync=True)
     """GPU parameters to pass to deck.gl.
 
-    **This is an advanced API. The vast majority of users should not need to touch this
-    setting.**
-
-    !!! Note
+    !!! Note "This is an advanced API. The vast majority of users should not need to touch this setting."
 
         The docstring below is copied from upstream deck.gl documentation. Any usage of
         `GL` refers to the constants defined in [`@luma.gl/constants`
@@ -402,6 +519,7 @@ class Map(BaseAnyWidget):
 
         Args:
             layers: New layers to add to the map. This can be:
+
                 - a layer instance
                 - a list or tuple of layer instances
                 - another `Map` instance, in which case its layers will be added to this
@@ -434,8 +552,9 @@ class Map(BaseAnyWidget):
         elif reset_zoom:
             self.view_state = compute_view(self.layers)  # type: ignore
 
-    def set_view_state(
+    def set_view_state(  # noqa: PLR0913
         self,
+        view_state: BaseViewState | None = None,
         *,
         longitude: float | None = None,
         latitude: float | None = None,
@@ -447,6 +566,9 @@ class Map(BaseAnyWidget):
 
         Any parameters that are unset will not be changed.
 
+        Args:
+            view_state: A complete view state object to set on the map.
+
         Keyword Args:
             longitude: the new longitude to set on the map. Defaults to None.
             latitude: the new latitude to set on the map. Defaults to None.
@@ -455,24 +577,38 @@ class Map(BaseAnyWidget):
             bearing: the new bearing to set on the map. Defaults to None.
 
         """
-        view_state = (
-            self.view_state._asdict()  # type: ignore
-            if self.view_state is not None
-            else DEFAULT_INITIAL_VIEW_STATE
-        )
+        if view_state is not None:
+            self.view_state = view_state
+            return
 
+        current_view_state = self.view_state
+
+        changes = {}
         if longitude is not None:
-            view_state["longitude"] = longitude
+            changes["longitude"] = longitude
         if latitude is not None:
-            view_state["latitude"] = latitude
+            changes["latitude"] = latitude
         if zoom is not None:
-            view_state["zoom"] = zoom
-        if pitch is not None:
-            view_state["pitch"] = pitch
-        if bearing is not None:
-            view_state["bearing"] = bearing
+            changes["zoom"] = zoom
 
-        self.view_state = view_state
+        # Only params allowed by globe view state
+        if isinstance(current_view_state, GlobeViewState):
+            self.view_state = replace(current_view_state, **changes)
+            return
+
+        # Add more params allowed by map view state
+        if pitch is not None:
+            changes["pitch"] = pitch
+        if bearing is not None:
+            changes["bearing"] = bearing
+
+        if isinstance(current_view_state, MapViewState):
+            self.view_state = replace(current_view_state, **changes)
+            return
+
+        raise TypeError(
+            "Can only set MapViewState or GlobeViewState parameters individually via set_view_state.\nFor other view state types, pass a complete view_state object.",
+        )
 
     def fly_to(  # noqa: PLR0913
         self,
@@ -507,17 +643,17 @@ class Map(BaseAnyWidget):
                 specified speed is ignored.
 
         """  # noqa: D210
-        if not isinstance(longitude, (int, float)):
+        if not isinstance(longitude, (int, float, np.number)):
             raise TypeError(
                 f"Expected longitude to be an int or float, got {type(longitude)}",
             )
 
-        if not isinstance(latitude, (int, float)):
+        if not isinstance(latitude, (int, float, np.number)):
             raise TypeError(
                 f"Expected latitude to be an int or float, got {type(latitude)}",
             )
 
-        if not isinstance(zoom, (int, float)):
+        if not isinstance(zoom, (int, float, np.number)):
             raise TypeError(f"Expected zoom to be an int or float, got {type(zoom)}")
 
         data = {
@@ -565,34 +701,7 @@ class Map(BaseAnyWidget):
             If `filename` is not passed, returns the HTML content as a `str`.
 
         """
-
-        def inner(fp: str | Path | TextIO | IO[str]) -> None:
-            original_height = self.height
-            try:
-                with self.hold_trait_notifications():
-                    self.height = "100%"
-                    embed_minimal_html(
-                        fp,
-                        views=[self],
-                        title=title or "Lonboard export",
-                        template=_HTML_TEMPLATE,
-                        drop_defaults=False,
-                        # Necessary to pass the state of _this_ specific map. Otherwise, the
-                        # state of all known widgets will be included, ballooning the file size.
-                        state=dependency_state((self), drop_defaults=False),
-                    )
-            finally:
-                # If the map had a height before the HTML was generated, reset it.
-                self.height = original_height
-
-        if filename is None:
-            with StringIO() as sio:
-                inner(sio)
-                return sio.getvalue()
-
-        else:
-            inner(filename)
-            return None
+        return map_to_html(self, filename=filename, title=title)
 
     def as_html(self) -> HTML:
         """Render the current map as a static HTML file in IPython.
@@ -623,6 +732,9 @@ class Map(BaseAnyWidget):
 
         return HTML(self.to_html())
 
-    @traitlets.default("view_state")
+    @t.default("view_state")
     def _default_initial_view_state(self) -> dict[str, Any]:
-        return compute_view(self.layers)  # type: ignore
+        if self.view is None or isinstance(self.view, (MapView, GlobeView)):
+            return compute_view(self.layers)  # type: ignore
+
+        return {}
