@@ -4,4 +4,12 @@ These layers have not been as well tested as other layers. You may encounter cra
 unexpected behavior when using them.
 """
 
-from ._layer import ArcLayer, TextLayer, TripsLayer
+# Notes:
+#
+# - See module docstring of lonboard.layer for note on passing None as default value.
+
+from ._text import TextLayer
+
+__all__ = [
+    "TextLayer",
+]
